@@ -309,7 +309,7 @@ def readPYSTR(filename, headonly=False, **kwargs):
                 tester = float('nan')
             else:
                 tester = '-'
-            array[idx] = np.asarray(array[idx]).astype(object)
+            array[idx] = np.asarray(array[idx],dtype=object)
             if not False in checkEqual3(array[idx]) and ar[0] == tester:
                 array[idx] = np.asarray([])
 
@@ -715,7 +715,7 @@ def readPYBIN(filename, headonly=False, **kwargs):
         headskip = True
 
     if debug:
-        print ("PYBIN: reading data here")
+        print ("PYBIN: reading data ...")
 
     theday = extractDateFromString(filename)
     try:
@@ -730,6 +730,7 @@ def readPYBIN(filename, headonly=False, **kwargs):
         getfile = True
     logbaddata = False
 
+    #t1 = datetime.utcnow()
     if getfile:
         logger.info("readPYBIN: %s Format: PYBIN" % filename)
         if debug:
@@ -905,15 +906,22 @@ def readPYBIN(filename, headonly=False, **kwargs):
             print("Not implemented")
             pass
 
-        array = np.asarray([np.asarray(el).astype(object) for el in array])
-        stream.ndarray = array
+        if debug:
+            print ('readPYBIN: array: {}'.format(len(array)))
+
+        array = [np.asarray(el,dtype=object) for el in array]
 
         if len(stream.ndarray[0]) > 0:
             logger.debug("readPYBIN: Imported bin as ndarray")
             stream.container = [LineStruct()]
             # if unequal lengths are found, then usually txt and bin files are loaded together
 
-    return stream
+    #t2 = datetime.utcnow()
+    #print ("Duration:", (t2-t1).total_seconds())
+    stream.header["DataFormat"] = "PYBIN"
+
+    return DataStream([LineStruct()], stream.header, np.asarray(array,dtype=object))
+
 
 
 def writePYSTR(datastream, filename, **kwargs):
