@@ -217,7 +217,6 @@ def readRMRCS(filename, headonly=False, **kwargs):
     getfile = True
 
     debug = kwargs.get('debug')
-    debug = True
     if debug:
         print ("RCS: found data from Richards Perl script")
 
@@ -306,6 +305,7 @@ def readRMRCS(filename, headonly=False, **kwargs):
         headers["SensorSerialNum"] = "20160114"
         headers["SensorRevision"] = "0001"
         headers["SensorModule"] = "RCS"
+        headers["DataFormat"] = "RCS-Perl"
         headers["SensorGroup"] = "environment"
         headers["SensorDataLogger"] = "{}".format(fieldpoint)
     else:
@@ -1000,7 +1000,7 @@ def readGRAVSG(filename, headonly=False, **kwargs):
             #    continue
             elif line.startswith('[TSF-file]'):
                 contline = line.split()
-                stream.header['DataFormat'] = contline[1]
+                stream.header['DataFormat'] = "GRAVSG{}".format(contline[1])
             elif line.startswith('[TIMEFORMAT]'):
                 contline = line.split()
                 val = contline[1]
@@ -1150,7 +1150,7 @@ def readGRAVSG(filename, headonly=False, **kwargs):
     for idx, elem in enumerate(array):
         array[idx] = np.asarray(array[idx])
 
-    stream = DataStream([LineStruct()],stream.header,np.asarray(array))
+    stream = DataStream([LineStruct()],stream.header,np.asarray(array,dtype=object))
 
     fh.close()
     return stream
