@@ -28,6 +28,7 @@ DEPENDENCIES:
                 .format_noaa
                 .format_latex
                 .format_wik
+                -format_tsf
                 .format_wic
                 .format_sfs
                 .format_bdv
@@ -59,6 +60,7 @@ from magpy.lib.format_qspin import *
 #from magpy.lib.format_env05 import *
 from magpy.lib.format_cr800 import *
 from magpy.lib.format_iono import *
+from magpy.lib.format_tsf import *
 
 # IMPORT GENERAL PURPOSE FORMATS:
 from magpy.lib.format_iaga02 import *
@@ -149,6 +151,9 @@ def isFormat(filename, format_type):
     elif (format_type == "PYBIN"):
         if (isPYBIN(filename)):
             return True
+    elif (format_type == "GFZINDEXJSON"):
+        if (isGFZINDEXJSON(filename)):
+            return True
     elif (format_type == "COVJSON"):
         if (isCOVJSON(filename)):
             return True
@@ -167,6 +172,9 @@ def isFormat(filename, format_type):
     elif (format_type == "LNM"): # Conrad Observatory LaserNiederschlagsMonitor - LNM Telegram 5 files
         if (isLNM(filename)):
             return True
+    elif (format_type == "TSF"):  # Data from the iGrav and SG gravity system
+        if (isTSF(filename)):
+            return True
     elif (format_type == "GRAVSG"): # Data from the Conrad Observatory SG gravity system
         if (isGRAVSG(filename)):
             return True
@@ -287,7 +295,7 @@ def isFormat(filename, format_type):
     elif (format_type == "CSV"): # Basic CSV data
         if (isCSV(filename)):
             return True
-    elif (format_type in ["PYNC", "AUTODIF", "SERMUL", "SERSIN", "LATEX"]): # Not yet supported
+    elif (format_type in ["PYNC", "AUTODIF","AUTODIFABS", "SERMUL", "SERSIN", "LATEX"]): # Not yet supported
         return False
     elif (format_type == "UNKOWN"): # Unkown
         return False
@@ -338,6 +346,8 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
         return readPYCDF(filename, headonly, **kwargs)
     elif (format_type == "PYBIN"):
         return readPYBIN(filename, headonly, **kwargs)
+    elif (format_type == "GFZINDEXJSON"):
+        return readGFZINDEXJSON(filename, headonly, **kwargs)
     elif (format_type == "JSON"):
         return readJSON(filename, headonly, **kwargs)
     elif (format_type == "GSM19"):
@@ -364,6 +374,8 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
     #    return readENV05(filename, headonly, **kwargs)
     elif (format_type == "USBLOG"):
         return readUSBLOG(filename, headonly, **kwargs)
+    elif (format_type == "TSF"):
+        return readTSF(filename, headonly, **kwargs)
     elif (format_type == "GRAVSG"):
         return readGRAVSG(filename, headonly, **kwargs)
     elif (format_type == "IWT"):
